@@ -19,7 +19,7 @@ def imports() -> str:
     lines = [
         "from __future__ import annotations",
         "from enum import Enum",
-        "from datetime import datetime",
+        "from datetime import datetime, date",
         "from pydantic import BaseModel, Field",
         f"from dgraph_orm import {ORM_MODEL_NAME}, Node, GQLException",
         "from dgraph_orm.resolver import Params, Resolver",
@@ -736,6 +736,8 @@ import strawberry
 
 class EnhancedJSONEncoder(json.JSONEncoder):
     def default(self, o):
+        if isinstance(o, (datetime, date)):
+            return o.isoformat()
         if dataclasses.is_dataclass(o):
             return dataclasses.asdict(o)
         return super().default(o)
